<?php
/**
 * Theme functions file
 *
 * Contains all of the Theme's setup functions, custom functions,
 * custom hooks and Theme settings.
 * 
 * @since      0.0.1
 * @author     Satrya <satrya@satrya.me>
 * @copyright  Copyright (c) 2012 - 2014, Satrya
 * @link       http://satrya.me/wordpress-themes/tiga/
 * @license    http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 *
 * @since 0.0.1
 */
if ( ! isset( $content_width ) ) {
	$content_width = 620; /* pixels */
}

/* Load constants file. */
require_once( trailingslashit( get_template_directory() ) . 'includes/constants.php' );

/* Do theme setup on the 'after_setup_theme' hook. */
add_action( 'after_setup_theme', 'tiga_setup' );

/* Load additional libraries a little later. */
add_action( 'after_setup_theme', 'tiga_load_libraries', 11 );

/**
 * Theme setup function. This function adds support for theme features and defines the default theme
 * actions and filters.
 * 
 * @since 0.0.1
 */
function tiga_setup() {
	
	/* Make tiga available for translation. */
	load_theme_textdomain( 'tiga', trailingslashit( THEME_DIR ) . 'languages' );

	/* Editor styles. */
	add_editor_style( 'editor-style.css' );

	/* Add default posts and comments RSS feed links to head. */
	add_theme_support( 'automatic-feed-links' );

	/* Setup the WordPress core custom background feature. */
	add_theme_support( 
		'custom-background',
		array(
			'default-image' => trailingslashit( TIGA_IMAGE ) . 'pattern.png',
		)
	);

	/* Setup the custom menu. */
	register_nav_menus(
		array(
			'primary'   => __( 'Primary Navigation'  , 'tiga' ),
			'secondary' => __( 'Secondary Navigation', 'tiga' )
		)
	);

	/* Enable Post Thumbnails support. */
	add_theme_support( 'post-thumbnails' );

	/* Setup the custom header. */
	$args = array(
		'width'         => 200,
		'height'        => 80,
		'flex-height'   => true,
		'flex-width'    => true,		
		'header-text'   => false,
		'uploads'       => true,
	);
	add_theme_support( 'custom-header', $args );

	/* Enable support for HTML5 markup. */
	add_theme_support(
		'html5',
		array(
			'comment-list',
			'search-form',
			'comment-form',
			'gallery',
		)
	);

	/* Add custom image sizes. */
	add_action( 'init', 'tiga_add_image_sizes' );

	/* Add custom image sizes custom name. */
	add_filter( 'image_size_names_choose', 'tiga_custom_name_image_sizes' );

	/* Remove gallery inline style */
	add_filter( 'use_default_gallery_style', '__return_false' );

	/* Allow shortcode in widget. */
	add_filter( 'widget_text', 'do_shortcode' );

}

/**
 * Loads some additional functions.
 *
 * @since 1.7
 */
function tiga_load_libraries() {

	define( 'OPTIONS_FRAMEWORK_DIRECTORY', trailingslashit( get_template_directory_uri() ) . 'includes/library/' );
	require_once dirname( __FILE__ ) . '/includes/library/options-framework.php';

	/* Loads the custom theme functions. */
	require( trailingslashit( TIGA_INCLUDES ) . 'theme-functions.php' );

	/* Loads enqueue scripts for theme usage. */
	require( trailingslashit( TIGA_INCLUDES ) . 'enqueue.php' );

	/* Loads the custom template tags. */
	require( trailingslashit( TIGA_INCLUDES ) . 'template-tags.php' );

	/* Loads the theme hooks. */
	require( trailingslashit( TIGA_INCLUDES ) . 'hooks.php' );

	/* Options panel extras. */
	require( trailingslashit( TIGA_INCLUDES ) . 'options-functions.php' );

}

/**
 * Adds custom image sizes.
 *
 * @since 1.0
 */
function tiga_add_image_sizes() {
	add_image_size( 'tiga-140px' , 140, 140, true );
	add_image_size( 'tiga-300px' , 300, 130, true );
	add_image_size( 'tiga-700px' , 700, 300, true );
	add_image_size( 'tiga-620px' , 620, 350, true );
	add_image_size( 'tiga-460px' , 460, 300, true );
}

/**
 * Adds custom image sizes custom name.
 *
 * @since 1.0
 */
function tiga_custom_name_image_sizes( $sizes ) {
    $sizes['tiga-140px'] = __( 'Small Thumbnail' , 'tiga' );
    $sizes['tiga-300px'] = __( 'Medium Thumbnail', 'tiga' );
    $sizes['tiga-700px'] = __( 'Featured'        , 'tiga' );
    $sizes['tiga-620px'] = __( 'Medium Featured' , 'tiga' );
    $sizes['tiga-460px'] = __( 'Home Slides'     , 'tiga' );
 
    return $sizes;
}

/**
 * Count the number of widgets to enable dynamic classes
 *
 * @since 1.0
 */
function tiga_dynamic_sidebar_class( $sidebar_id ) {

	$sidebars  = wp_get_sidebars_widgets();
	$get_count = count( $sidebars[$sidebar_id] );

	$class = '';

	switch ( $get_count ) {
		case '1':
			$class = 'one';
			break;
		case '2':
			$class = 'two';
			break;
		case '3':
			$class = 'three';
			break;
		case '4':
			$class = 'four';
			break;
	}

	if ( $class )
		echo $class;

}

/**
 * Tiga site title.
 *
 * @since 1.4
 */
function tiga_site_title() {	

	$titletag  = ( is_front_page() ) ? 'h1' : 'h2';

	if ( get_header_image() ) {
		echo '<' . $titletag . ' class="site-logo">' . "\n";
			echo '<a href="' . get_home_url() . '" title="' . get_bloginfo( 'name' ) . '" rel="home">' . "\n";
				echo '<img class="logo" src="' . get_header_image() . '" alt="' . get_bloginfo( 'name' ) . '" />' . "\n";
			echo '</a>' . "\n";
		echo '</' . $titletag . '>' . "\n";
	} else {
		echo '<' . $titletag . ' class="site-title">' . "\n";
			echo '<a href="' . get_home_url() . '" title="' . get_bloginfo( 'name' ) . '" rel="home">' . get_bloginfo( 'name' ) . '</a>' . "\n";
		echo '</' . $titletag . '>' . "\n";
		echo '<div class="site-description">' . get_bloginfo( 'description' ) . '</div>';
	}

}