<?php
/**
 * Custom theme functions for theme usage.
 *
 * @since      0.0.1
 * @author     Satrya <satrya@satrya.me>
 * @copyright  Copyright (c) 2012 - 2014, Satrya
 * @link       http://satrya.me/wordpress-themes/tiga/
 * @license    http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 */

/* Formatted 'wp_title' output. */
add_filter( 'wp_title', 'tiga_title', 10, 2 );

/* Replaces excerpt "[...]". */
add_filter( 'excerpt_more', 'tiga_auto_excerpt_more' );

/* Adds "Continue Reading" to the post excerpt. */
add_filter( 'get_the_excerpt', 'tiga_custom_excerpt_more' );

/* Stop more link from jumping to middle of page. */
add_filter( 'the_content_more_link', 'tiga_remove_more_jump_link' );

/* Adds custom classes to the array of body classes. */
add_filter( 'body_class', 'tiga_body_classes' );

/* Filter in ID on image attachment pages. */
add_filter( 'attachment_link', 'tiga_enhanced_image_navigation', 10, 2 );

/* Customize tag cloud widget. */
add_filter( 'widget_tag_cloud_args', 'tiga_new_tag_cloud' );

/* HTML5 tag for image and caption. */
add_filter( 'img_caption_shortcode', 'tiga_html5_caption', 10, 3 );

/* Removes default styles set by WordPress recent comments widget. */
add_action( 'widgets_init', 'tiga_remove_recent_comments_style' );

/* Filter the main loop on blog-slider page. */
add_action( 'pre_get_posts', 'tiga_filter_query' );

/* Embed width defaults. */
add_filter( 'embed_defaults', 'tiga_embed_defaults' );

/* Register additional widgets. */
add_action( 'widgets_init', 'tiga_register_widgets' );

/* Register custom sidebar. */
add_action( 'widgets_init', 'tiga_register_custom_sidebars' );

/* Theme settings location. */
add_filter( 'options_framework_location', 'tiga_theme_settings_location' );

/**
 * Creates a nicely formatted and more specific title element text
 * for output in head of document, based on current view.
 *
 * @since 1.4
 */
function tiga_title( $title, $sep ) {
	global $paged, $page;

	if ( is_feed() )
		return $title;

	// Add the site name.
	$title .= get_bloginfo( 'name' );

	// Add the site description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		$title = "$title $sep $site_description";

	// Add a page number if necessary.
	if ( $paged >= 2 || $page >= 2 )
		$title = "$title $sep " . sprintf( __( 'Page %s', 'tiga' ), max( $paged, $page ) );

	return $title;
}

/**
 * Returns a "Continue Reading" link for excerpts
 *
 * @since 0.0.1
 */
function tiga_continue_reading_link() {
	return ' <a href="'. esc_url( get_permalink() ) . '">' . __( 'Continue reading <span class="meta-nav">&rarr;</span>', 'tiga' ) . '</a>';
}

/**
 * Replaces "[...]" (appended to automatically generated excerpts) with 
 * an ellipsis and tiga_continue_reading_link().
 *
 * @since 0.0.1
 */
function tiga_auto_excerpt_more( $more ) {
	return ' &hellip;' . tiga_continue_reading_link();
}

/**
 * Adds a pretty "Continue Reading" link to custom post excerpts.
 *
 * @since 0.0.1
 */
function tiga_custom_excerpt_more( $output ) {

	if ( has_excerpt() && ! is_attachment() ) {
		$output .= tiga_continue_reading_link();
	}
	return $output;

}

/**
 * Stop more link from jumping to middle of page.
 *
 * @since 0.0.1
 */
function tiga_remove_more_jump_link($link) {

	$offset = strpos($link, '#more-');
	if ($offset) {
		$end = strpos($link, '"',$offset);
	}
	if ($end) {
		$link = substr_replace($link, '', $offset, $end-$offset);
	}
	return $link;

}

/**
 * Adds custom classes to the array of body classes.
 *
 * @since 0.0.1
 */
function tiga_body_classes( $classes ) {
	if ( is_multi_author() ) {
		$classes[] = 'multi-author';
	}

	return $classes;
}

/**
 * Filter in a link to a content ID attribute for the next/previous 
 * image links on image attachment pages
 *
 * @since 0.0.1
 */
function tiga_enhanced_image_navigation( $url, $id ) {

	if ( ! is_attachment() && ! wp_attachment_is_image( $id ) )
		return $url;

	$image = get_post( $id );
	if ( ! empty( $image->post_parent ) && $image->post_parent != $id )
		$url .= '#main';

	return $url;

}

/**
 * Customize tag cloud widget.
 *
 * @since 0.0.1
 */
function tiga_new_tag_cloud( $args ) {
	$args['largest']  = 12;
	$args['smallest'] = 12;
	$args['unit']     = 'px';

	return $args;
}

/**
 * HTML5 tag for image and caption.
 *
 * @since 0.2.1
 */
function tiga_html5_caption( $output, $attr, $content ) {

	/* We're not worried abut captions in feeds, so just return the output here. */
	if ( is_feed() )
		return $output;

	/* Set up the default arguments. */
	$defaults = array(
		'id' => '',
		'align' => 'alignnone',
		'width' => '',
		'caption' => ''
	);

	/* Merge the defaults with user input. */
	$attr = shortcode_atts( $defaults, $attr );

	/* If the width is less than 1 or there is no caption, return the content wrapped between the [caption]< tags. */
	if ( 1 > $attr['width'] || empty( $attr['caption'] ) )
		return $content;

	/* Set up the attributes for the caption <div>. */
	$attributes = ( !empty( $attr['id'] ) ? ' id="' . esc_attr( $attr['id'] ) . '"' : '' );
	$attributes .= ' class="wp-caption ' . esc_attr( $attr['align'] ) . '"';
	$attributes .= ' style="width: ' . esc_attr( $attr['width'] ) . 'px"';

	/* Open the caption <figure>. */
	$output = '<figure' . $attributes .'>';

	/* Allow shortcodes for the content the caption was created for. */
	$output .= do_shortcode( $content );

	/* Append the caption text. */
	$output .= '<figcaption class="wp-caption-text">' . $attr['caption'] . '</figcaption>';

	/* Close the caption </figure>. */
	$output .= '</figure>';

	/* Return the formatted, clean caption. */
	return $output;

}

/**
 * Removes default styles set by WordPress recent comments widget.
 *
 * @since 0.0.1
 */
function tiga_remove_recent_comments_style() {

	global $wp_widget_factory;
	remove_action( 'wp_head', array( $wp_widget_factory->widgets['WP_Widget_Recent_Comments'], 'recent_comments_style' ) );

}

/**
 * Filter the main loop.
 *
 * @since 2.0
 */
function tiga_filter_query( $query ) {
	
	if( is_page_template( 'page-templates/blog-slider.php' ) )
		$query->set( 'post__not_in', get_option( 'sticky_posts' ) );
	
}

/**
 * Overwrites the default widths for embeds.  This is especially useful for making sure videos properly
 * expand the full width on video pages.  This function overwrites what the $content_width variable handles
 * with context-based widths.
 *
 * @since 1.0
 */
function tiga_embed_defaults( $args ) {
	
	$args['width'] = 620;
	
	$layout = of_get_option( 'tiga_layouts' );

	if ( 'onecolumn' == $layout )
		$args['width'] = 700;

	return $args;
}

/**
 * Registers extra widgets.
 * 
 * @since 1.0
 */
function tiga_register_widgets() {

	require_once( trailingslashit( TIGA_CLASSES ) . 'widget-social.php' );
	register_widget( 'tiga_social' );

	require_once( trailingslashit( TIGA_CLASSES ) . 'widget-subscribe.php' );
	register_widget( 'tiga_subscribe' );

	require_once( trailingslashit( TIGA_CLASSES ) . 'widget-fbfans.php' );
	register_widget( 'tiga_fb_box' );

}

/**
 * Registers custom sidebars.
 * 
 * @since 0.0.1
 */
function tiga_register_custom_sidebars() {

    register_sidebar(array(
    	'id'			=> 'primary',
		'name'          => __( 'Primary', 'tiga'),
		'description'   => __( 'Primary sidebar, appears on all pages.', 'tiga' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<span class="widget-title">',
		'after_title'   => '</span>',
	));
	
	register_sidebar(array(
		'id'			=> 'subsidiary',
		'name'          => __( 'Subsidiary', 'tiga'),
		'description'   => __( 'Subsidiary sidebar, appears on the footer side of your site.', 'tiga' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<span class="widget-title">',
		'after_title'   => '</span>',
	));

	register_sidebar(array(
		'id'			=> 'above-content',	
		'name'          => __( 'Above Single Post Content', 'tiga'),
		'description'   => __( 'This sidebar appears on the single post, above the content.', 'tiga' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<span class="widget-title">',
		'after_title'   => '</span>',
	));

	register_sidebar(array(
		'id'			=> 'below-content',	
		'name'          => __( 'Below Single Post Content', 'tiga'),
		'description'   => __( 'This sidebar appears on the single post, below the content.', 'tiga' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<span class="widget-title">',
		'after_title'   => '</span>',
	));

	register_sidebar(array(
		'id'			=> 'home',	
		'name'          => __( 'Custom Home Page', 'tiga'),
		'description'   => __( 'This sidebar appears on custom home page template.', 'tiga' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<span class="widget-title">',
		'after_title'   => '</span>',
	));

}

/**
 * Theme settings.
 *
 * @since 1.7
 */
function tiga_theme_settings_location() {
	return array( 'includes/options.php' );
}
?>